//////////////////////////////////////////////////////////////////////////////////////////

bmap core1_tga = <core1.tga>;
bmap core2_tga = <core2.tga>;
bmap debristrail_tga = <debristrail.tga>;
bmap smoke_tga = <smoke.tga>;

//////////////////////////////////////////////////////////////////////////////////////////

string exploring_tga = <exploring.tga>;
string exploflare_pcx = <exploflare.pcx>;
string explosion_pcx = <explo+20.pcx>;
string gibbit_mdl = <gibbit.mdl>;

//////////////////////////////////////////////////////////////////////////////////////////

sound explostart_wav = <explostart.wav>;
sound explomid_wav = <explomid.wav>;
sound exploend_wav = <exploend.wav>; 

//////////////////////////////////////////////////////////////////////////////////////////

function explosion_core();
function core_fade();
function debris_trail();
function fade_debtrail();
function explosion_ring();
function fade_smoke();
function explosion_sprite1();
function explosion_sprite2();

//////////////////////////////////////////////////////////////////////////////////////////

function explosion_core()
{
	if (random(1) > 0.5)
	{
		my.bmap = core1_tga;
	}
	else
	{
		my.bmap = core2_tga;
	}	
	my.transparent = on;
	my.flare = on;
	my.bright = on;
	my.size = random(30) + 20;
	my.alpha = 100;
	my.function = core_fade;
}

function core_fade()
{
	if (my.alpha > 50)
	{
		my.size += 2 * time;
	}
	else
	{
		my.size -= 2 * time;
	}
	my.alpha -= 3 * time;
	if (my.alpha < 0) 
	{ 
		my.lifespan = 0; 
	}
}

function explosion_ring()
{
	my.passable = on;
	my.scale_x = 0.1;
	my.scale_y = 0.1;
	my.tilt = 90;
	my.oriented = on;
	my.bright = on;
	my.flare = on;
	my.transparent = on;
	my.alpha = 100;
	my.ambient = 100;
	my.lightred = 255;
	my.lightgreen = 200;
	my.lightrange = 100;
	while (my.scale_x < 4)
	{
		my.alpha -= 10 * time;
		my.lightrange += 50 * time;
		my.scale_x += 0.5 * time;
		my.scale_y = my.scale_x;
		wait(1);
	}
	ent_remove(my);
}

function explosion_sprite1()
{
	my.passable = on;
	my.facing = on;
	my.bright = on;
	my.flare = on;
	my.alpha = 100;
	my.ambient = 100;
	while (my.scale_x < 4)
	{
		my.scale_x += 1 * time;
		my.scale_y = my.scale_x;
		my.alpha -= 10 * time;
		my.roll += 25 * time;
		wait(1);
	}
	ent_remove(my);
}

function explosion_sprite2()
{
	my.passable = on;
	my.facing = on;
	my.bright = on;
	my.flare = on;
	my.ambient = 100;
	my.red = 255;
	my.lightrange = 100;
	while (my.frame < 20)
	{
		my.frame += 1 * time;
		my.scale_x += 0.1 * time;
		my.scale_y = my.scale_x;
		my.lightrange = 300 - random(100);
		wait(1);
	}
	ent_remove(my);
}

function move_gibbits()
{
	var gib_coords;
	var gib_speed;
	my.passable = on;
	my.scale_x = 0.5 + random(1);
	my.scale_y = my.scale_x;
	my.scale_z = my.scale_x;
	vec_set (gib_coords, my.x);
	gib_speed.x = (10 - random(20)) * time;
	gib_speed.y = (10 - random(20)) * time;
	gib_speed.z = (20 + random(10)) * time;
	my.skill10 = 10;
	while (my.skill10 > 0)
	{
		if (vec_dist (my.x, gib_coords.x) > 70) 
		{
			my.passable = off;
		}
		ent_move (nullvector, gib_speed);
		effect (debris_trail, 1, my.x, nullvector);	
		if (bounce.z != 0)
		{
			gib_speed.z = -(gib_speed.z * min(0.8, random(1)));
			if (gib_speed.z < 0.1)
			{
				gib_speed.x = 0;
				gib_speed.y = 0;
				gib_speed.z = 0;
			}
		}
		gib_speed.z -= 2 * time;
		my.skill10 -= 0.3 * time;
		wait (1);
	}
	my.transparent = on;
	my.alpha = 100;
	while (my.alpha > 0)
	{
		my.alpha -= 3 * time;
		wait (1);
	}
	ent_remove (my);
}

function debris_trail()
{
	my.bmap = debristrail_tga;
	my.flare = on;
	my.bright = on;
	my.size = 2;
	my.alpha = 30;
	my.function = fade_debtrail;
}

function fade_debtrail()
{
	my.size += 0.8 * time;
	my.alpha -= 1.5 * time;
	if (my.alpha < 0)
	{ 
		my.lifespan = 0; 
	}
}

function particle_smoke()
{
	my.bmap = smoke_tga;
	my.vel_x = 2 - random(4);
	my.vel_y = 2 - random(4);
	my.vel_z = 2 + random(1);
	my.lifespan = 200;
	my.flare = on;
	my.transparent = on;
	my.alpha = 50;
	my.move = on;
	my.size = 50;
	my.function = fade_smoke;
}

function fade_smoke()
{
	my.size += 0.5 * time;
	my.alpha -= 0.4 * time;
	if (my.alpha < 0)
	{
		my.lifespan = 0;
	}
}

function start_explosion(coordinates)
{
	var sound_volume;
	var number_of_gibbits;
	sound_volume = 30000 / (vec_dist(coordinates.x, camera.x) + 100);
	snd_play (explostart_wav, sound_volume, 0);
	effect (explosion_core, 10 + random(10), coordinates, nullvector);
	sleep (0.5);
	ent_create (exploring_tga, coordinates, explosion_ring);
	snd_play (explomid_wav, sound_volume, 0);
	sleep (0.1);
	ent_create (exploflare_pcx, coordinates, explosion_sprite1);
	sleep (0.1);
	ent_create (explosion_pcx, coordinates, explosion_sprite2);
	sleep (0.1);
	number_of_gibbits = random(15) + 5;
	while (number_of_gibbits > 0) // while without wait!
	{
		ent_create (gibbit_mdl, coordinates, move_gibbits);
		number_of_gibbits -= 1;
	}
	snd_play (exploend_wav, sound_volume, 0);
	sleep (0.5);
	effect (particle_smoke, random(20) + 10, coordinates, nullvector);
}

function explo_test()
{
	start_explosion (vector(0, 0, 100));
}

on_e = explo_test;

function destroy_me()
{
	start_explosion (vector(my.x, my.y, my.z + 20));
	sleep (0.5);
	my.invisible = on;
	my.passable = on;
}

action explodable_barrel 
{
	my.enable_impact = on;	
	my.enable_entity = on;
	my.enable_shoot = on;
	my.event = destroy_me;
}
