// this script contains the actions and functions that will be used in the first level
///////////////////////////////////////////////////////////////////////////////////////////

font figures_font = <font.tga>, 15, 15;
font score_font = <scorefont.tga>, 15, 15; // same font with a blueish touch
font system_font = <system.pcx>, 10, 12;

///////////////////////////////////////////////////////////////////////////////////////////

entity* lbase; // pointer to the landing base
entity* human; // pointer to the man that gets out of the ship

entity* tile1;
entity* tile2;
entity* tile3;
entity* tile4;
entity* tile5;
entity* tile6;
entity* tile7;
entity* tile8;
entity* tile9;

///////////////////////////////////////////////////////////////////////////////////////////

function move_asteroid();
function destroy_asteroid();
function fire_rocket();
function move_rocket();
function remove_rocket();
function explode_me();
function particle_trail();
function fade_particles();
function player_was_hit();
function particle_smoke();
function compute_time();
function move_human();
function logical_help();
function h1_clicked();
function h2_clicked();
function h3_clicked();
function v1_clicked();
function v2_clicked();
function v3_clicked();
function give_bonus();

///////////////////////////////////////////////////////////////////////////////////////////

var track_handle = 0; // sound handle for the music track in level1
var ready_to_play = 0; // will be set to 1 when the player can start to play
var score_value = 0; // will be converted to a string and displayed on the screen
var player_is_dead = 0;
var temp_var; // just a temporary variable
var players_shield;
var players_ammo;
var landing = 0; // will be set to 1 when the ships prepares to land
var logical_ended = 0;
var minimum_bonus = 10; // minimum bonus = 10
var temp_bonus = 100; // maximum bonus = 100
var level2_ready = 0; // will be set to 1 when the player prepares to enter the 2nd level

var status1;
var status2;
var status3;
var status4;
var status5;
var status6;
var status7;
var status8;
var status9;

///////////////////////////////////////////////////////////////////////////////////////////

string asteroid1_mdl = <asteroid1.mdl>;
string asteroid2_mdl = <asteroid2.mdl>;
string asteroid3_mdl = <asteroid3.mdl>;
string rocket_mdl = <rocket.mdl>;
string base_mdl = <base.mdl>;
string human_mdl = <human.mdl>;

string tilered_wmb = <tilered.wmb>;
string tilegreen_wmb = <tilegreen.wmb>;
string tileblue_wmb = <tileblue.wmb>;

string level2_wmb = <level2.wmb>;

string explo13_pcx = <explo+13.pcx>;

string score_str = "00000000";
string temp_str; // just a temporary string

///////////////////////////////////////////////////////////////////////////////////////////

sound engage_wav = <engage.wav>;
sound rocket_wav = <rocket.wav>;
sound destroyed_wav = <destroyed.wav>;
sound hit_wav = <hit.wav>;
sound bonus_wav = <bonus.wav>;
sound victory_wav = <victory.wav>;

///////////////////////////////////////////////////////////////////////////////////////////

bmap shield_tga = <shield.tga>;
bmap ammo_tga = <ammo.tga>;
bmap ptrail_tga = <ptrail.tga>;
bmap score_tga = <score.tga>;
bmap smoke_tga = <smoke.tga>;
bmap logical_pcx = <logical.pcx>; // mouse pointer for the logical game levels

///////////////////////////////////////////////////////////////////////////////////////////

panel shield_pan
{
	bmap = shield_tga;
	layer = 10;
	pos_x = 732;
	pos_y = 555;
	digits = 7, 15, 3, figures_font, 1, players_shield;
	flags = overlay, refresh, visible, transparent;
}

panel ammo_pan
{
	bmap = ammo_tga;
	layer = 10;
	pos_x = 0;
	pos_y = 555;
	digits = 12, 15, 3, figures_font, 1, players_ammo;
	flags = overlay, refresh, visible, transparent;
}

panel crosshair_pan
{
	bmap = pointer2_tga;
	layer = 20;	
	pos_x = 368;
	pos_y = 282;
	flags = transparent, overlay, refresh;
}

panel score_pan
{
	bmap = score_tga;
	layer = 10;	
	pos_x = 300;
	pos_y = 5;
	flags = overlay, refresh, visible;
}

text score_txt 
{ 
	pos_x = 380; 
	pos_y = 5; 
	layer = 10;
	font = score_font; 
	string = score_str;
	flags = visible;
} 

text logical_txt 
{ 
	pos_x = 190; 
	pos_y = 570; 
	layer = 10;
	font = system_font;
	string = "   Click the triangles until you create\n3 rows or 3 columns with identical colors";
} 

///////////////////////////////////////////////////////////////////////////////////////////

action planet_level1 // attached to the "planet" (a flat mdl, really)
{
	my.passable = on;
	fog_color = 1; // orange fog
	camera.clip_far = 100000; // works only with A6, delete this line if you own A5
	// clip_range = 100000; // remove the comment if you own A5
	camera.z = -100; // play with this value
	camera.fog_start = 50; // start drawing the fog close to the camera
	camera.fog_end = 20000; // close to the level boundary
	while (ready_to_play == 0) // shift the texture with this speed until the game starts
	{
		my.v += 3 * time;
		wait (1);
	}
	my.z -= 5000;
	my.ambient -= 30;
	while (landing == 0) // now shift with this speed until the player is dead
	{
		my.v += 2 * time; // slow down the movement a bit
		wait (1);
	}
	// stop moving when landing = 1
	while (level2_ready == 0) {wait (1);} // wait until the player moves on the the 2nd level
	while (my.ambient > -100)
	{
		my.ambient -= 10 * time;
		wait (1);
	}
}

action sky_level1
{
	my.passable = on;
	my.flare = on;
	my.ambient = -20;
	while (ready_to_play == 0) // keep the sky only during the cut scene
	{
		my.u -= 0.3 * time;
		wait (1);
	}
	ent_remove (my);
}

action player_level1
{
	compute_time();
	game_started = 1; // stop the loop that controls the mouse in function main
	player = my; // I'm the player
	players_ammo = 200;
	players_shield = 100;
	my.metal = on;
	my.ambient = 50;
	my.transparent = on;
	my.alpha = 100;
	my.enable_impact = on;
	my.enable_entity = on;
	my.event = player_was_hit;
	vec_set(temp, player.x); // rotate the camera towards player's ship from the very beginning
	vec_sub(temp, camera.x); 
	vec_to_angle(camera.pan, temp); 
	track_handle = media_play ("track1.wav", null, 50); // play the sound track
	sleep (0.5); // wait a bit before starting the ship
	fade_factor = 1000; // destroy the engine particles instantly (the ship has a huge speed now)
	my.engine = on;
	plasma_jet(65, 63); // use the "real" set of vertices for the engine now (we needed to use a different set of vertices for the top view)
	while (my.x < 3000)
	{
		my.roll += 1.5 * time;
		ent_playsound (my, engine1_wav, 300); // play the same engine sound that was used for the menu
		my.x += 52 * time;
		vec_set(temp, my.x); // rotate the camera towards player's ship all the time
		vec_sub(temp, camera.x); 
		vec_to_angle(camera.pan, temp); 
		wait (1);
	}
	ready_to_play = 1; // get rid of the sky and give control to the player
	my.x = -10000;
	my.y = 0;
	my.z = -100;
	my.roll = 0;

	crosshair_pan.visible = on;
	camera.x = -10230;
	camera.y = 0;
	camera.z = -50;
	camera.pan = 0;
	camera.tilt = 0;
	camera.fog_start = 15000;
	camera.fog_end = 40000;

	fade_factor = 100; // destroy the engine particles quickly (the ship has a small speed now)
	snd_play (engage_wav, 70, 0);	// the player can take control of the ship now
	while (players_shield > 0)
	{
		if (landing == 0)
		{
			camera.pan %= 360; // keep camera.pan in this range: 0...359
			camera.tilt += 10 * mouse_force.y * time;
			camera.pan -= 10 * mouse_force.x * time;
			if ((camera.pan > 30) && (camera.pan < 330)) // don't allow the player to blow our cover (if it looks back)
			{
				if (camera.pan < 180) 
				{
					camera.pan = 30;
				}
				else 
				{
					camera.pan = 330;
				}
			}
			if (camera.tilt < -35)
			{
				camera.tilt = -35;
			}
			if (camera.tilt > 25)
			{
				camera.tilt = 25;
			}
			my.pan = camera.pan;	
			my.tilt = camera.tilt;

			vec_set (temp_var, my.pos); // copy player's position to temp_var
			vec_to_screen(temp_var, camera); // now temp_var contains the 2D position (x, y) of the ship
			if ((abs(temp_var.x - 400) < 50) || (abs(temp_var.y - 300) < 40)) // the crosshair and the ship tend to overlap?
			{
				my.alpha = (abs(temp_var.x - 400) + abs(temp_var.y - 300));
			}
			else
			{
				if (my.alpha < 99)
				{
					my.alpha += 0.5 * time;
				}
			}

			if (((mouse_left == 1) || (key_space == 1)) && (players_ammo > 0))
			{
				fire_rocket();
			}

			if ((key_cul == on) && (my.y < 100))
			{
				my.y += 10 * time;
				if (my.roll < 30)
				{	
					my.roll += 3 * time;
				}
			}
			if ((key_cur == on) && (my.y > -100))
			{
				my.y -= 10 * time;
				if (my.roll > -30)
				{
					my.roll -= 3 * time;
				}
			}
			if (key_cul + key_cur == 0)
			{
				if (my.roll > 1)
				{
					my.roll -= 1 * time;
				}
				if (my.roll < -1)
				{
					my.roll += 1 * time;
				}
			}
		}
		else // landing = 1, prepare for landing
		{
			player.passable = on; // don't collide with the asteroids from now on
			player.transparent = off;
			camera.x = 500;
			camera.y = -200;
			camera.z = -2000;
			lbase.visible = on; // show the landing base
			crosshair_pan.visible = off; // hide the crosshair
			my.pan = 0; // reset the angles and the position of the ship
			my.tilt = 0;
			my.roll = 0;
			my.y = 0;
			while (player.x < 0)
			{
				if (player.z > -2270) {player.z -= 14 * time;}
				player.x += (vec_dist(player.x, lbase.x) / 60 + 2) * time;
				vec_set(temp, player.x); // rotate the camera towards player's ship from the very beginning
				vec_sub(temp, camera.x); 
				vec_to_angle(camera.pan, temp); 
				engine_handle = ent_playsound (my, engine1_wav, 400); // play the engine sound
				my.skill15 = vec_dist(player.x, lbase.x);
				if (my.skill15 < 1000)
				{
					snd_tune(engine_handle, 0, (my.skill15 / 10), 0);
				}
				wait (1);
			}
			sleep (2); // wait for 2 more seconds
			my.engine = off; // now shut down the engines
			temp.x = -35;
			temp.y = 0;
			temp.z = -2285;
			ent_create (human_mdl, temp, move_human); // create the human
			return; // let's get out of this function
		}
		wait (1);
	}
	// the player is dead here
	crosshair_pan.visible = off;
	camera.pan = 0;
	camera.tilt = -10;
	while (my.z > -1990) // come close to the planet
	{
		if (camera.tilt > -30) {camera.tilt -= 0.2 * time;}
		my.x += 30 * time;
		my.z -= 20 * time;
		my.roll += 10 * time;
		wait (1);
	}
	player_is_dead = 1; // stop the texture shifting for the planet
	my.skill10 = 10; // create a big explosion sprite for player's ship
	ent_create (explo13_pcx, my.pos, explode_me);
	my.tilt = -50; // choose a weird position for the ship
	my.passable = on;
	ent_playsound (my, hit_wav, 5000);
	fade_factor = 2;
	while (1)
	{
		temp.x = 3 - random(6);
		temp.y = 3 - random(6);
		temp.z = 4 + random(4);
		effect(particle_smoke, 10, my.pos, temp);
		wait (1);
	}		
}

action asteroid_maker
{
	var temp_var;
	my.passable = on;
	my.invisible = on;
	while (1)
	{
		if (logical_ended == 0)
		{
			temp.x = my.x;
		}
		else
		{
			temp.x = 20000;
		}
		temp.y = 5000 - random(10000); // -5,000 to 5,000
		temp.z = 1000 - random(2000);
		if (ready_to_play == 0) // game not started yet?
		{
			if ((temp.y > -500) && (temp.y < 500)) // the asteroid is too close to the player during the cut scene?
			{
				temp.y = 500; // then avoid the player until it is able to control the ship
			}
		}
		temp_var = random(1);
		if (temp_var < 0.33)
		{
			ent_create (asteroid1_mdl, temp, move_asteroid);
		}
		if ((temp_var >= 0.33) && (temp_var < 0.66))
		{
			ent_create (asteroid2_mdl, temp, move_asteroid);
		}
		if (temp_var > 0.66)
		{
			ent_create (asteroid3_mdl, temp, move_asteroid);
		}
		wait (2);
	}
}

function move_asteroid()
{
	var meteor_angle;
	var meteor_speed;
	my.ambient = -random(50);
	my.enable_impact = on;
	my.enable_entity = on;
	my.event = destroy_asteroid;
	my.scale_x = 5 + random(15);
	my.scale_y = my.scale_x;
	my.scale_z = my.scale_x;
	my.skill10 = my.scale_x; // store the scale in skill10 - we will use it to adjust the size of the explosion later
	meteor_angle.x = 3 - random(6); // random pan speed
	meteor_angle.y = 3 - random(6); // random tilt speed
	meteor_angle.z = 3 - random(6); // random roll speed
	meteor_speed.x = (-100 - random(80)) * time;
	meteor_speed.y = 0;
	meteor_speed.z = 0;
	while (my.x > -21000)
	{
		my.pan += meteor_angle.x * time;
		my.tilt += meteor_angle.y * time;
		my.roll += meteor_angle.z * time;
		move_mode = ignore_you + ignore_passable;
		ent_move (nullvector, meteor_speed);
		wait (1);
	}
	sleep (1);
	ent_remove (my);
}

function destroy_asteroid()
{
	if (you.skill40 == 1234) // hit by player's rocket?
	{
		score_value += int(1000 / (my.skill10 + 1)); // get bigger scores for smaller asteroids
	}
	my.x = -30000; // get out of the while loop inside function move_asteroid() and create a nice effect for the cut scene
	wait (1);
	my.event = null;
	ent_create (explo13_pcx, my.pos, explode_me);
	my.passable = on;
	my.invisible = on;
	ent_playsound (my, hit_wav, 1000);
	sleep (2); // wait until function explode_me reads the value stored in skill10 and until the sound is played
	ent_remove(my); // now remove it
}

function explode_me()
{
	my.oriented = on;
	my.flare = on;
	my.bright = on;
	my.ambient = random(100);
	my.passable = on;
	my.roll = random(360); // pick a random orientation
	my.skill30 = you.skill10; // store skill10 quickly because "you" will be removed soon
	while (my.frame < 14)
	{
		if (my.scale_x < my.skill30) // grow until you reach the value that was stored or set in skill10
		{
			my.scale_x += 5 * time;
			my.scale_y = my.scale_x;
		}
		my.frame += 1 * time;

		vec_set (temp.x, camera.x);
		vec_sub (temp.x, my.x);
		vec_to_angle (my.pan, temp); // turn towards the player to make sure that the explo looks great

		wait (1);
	}
	ent_remove (me);
}

function fire_rocket()
{
	proc_kill(4); // only one instance of this function is running
	while (mouse_left == 1) {wait (1);} 
	while (key_space == 1) {wait (1);}
	players_ammo -= 1;
	ent_create (rocket_mdl, player.pos, move_rocket);
	snd_play (rocket_wav, 50, 0);
}

function move_rocket()
{
	wait (1);
	my.enable_entity = on;
	my.enable_block = on;
	my.event = remove_rocket;
	my.pan = camera.pan;
	my.tilt = camera.tilt;
	my.skill40 = 1234; // I'm a rocket
	my.skill10 = 3; // default explosion scale for the rocket
	my.skill20 = 0;
	while (my.skill20 < 500)
	{
		my.skill1 = 500 * time;
		my.skill2 = 0;
		my.skill3 = 0;
		my.skill20 += 1 * time;
		ent_move (my.skill1, nullvector);

		temp.x = my.x;
		temp.y = my.y;
		temp.z = my.z;
		effect (particle_trail, 1, temp, normal);
		wait (1);
	}
	remove_rocket();
}

function particle_trail()
{
	temp.x = 100;
	temp.y = 0;
	temp.z = 0;
	vec_rotate (temp, you.pan); // use the same orientation with the rocket
	vec_add (my.vel_x, temp);
	my.alpha = 70 + random(30);
	my.bmap = ptrail_tga;
	my.size = 7;
	my.flare = on;
	my.bright = on;
	my.beam = on; // comment this line if your engine can't use "beam"
	my.move = on;
	my.lifespan = 30;
	my.function = fade_particles;
}

function fade_particles()
{
	my.alpha -= 100 * time;
	if (my.alpha < 0) {my.lifespan = 0;}
}

function remove_rocket()
{
	wait (1);
	my.event = null;
	ent_playsound (my, destroyed_wav, 1000); // play the explosion sound
	ent_create (explo13_pcx, my.pos, explode_me);
	my.invisible = on; // hide the rocket, keep ent_playsound playing
	sleep (2); // for 2 more seconds
	ent_remove(me); // now remove it
}

function player_was_hit()
{
	my.event = null; // stop reacting to events for now
	players_shield -= you.skill10 * 1.5; // bigger asteroids cause greater damage
	if (players_shield < 0) {players_shield = 0;}
	my.skill33 = 0;
	snd_play (hit_wav, 100, 0);
	if (players_shield > 0) // the game isn't over yet?
	{
		while (my.skill33 < 10)
		{
			camera.roll = 2 - random(4); // shake the player a bit
			my.skill33 += 1 * time;
			wait (1);
		}
		player.roll = 0; // then restore player's roll
	}
	my.event = player_was_hit;
}

function particle_smoke()
{
	my.alpha = 40 + random(50);
	my.bmap = smoke_tga;
	my.bright = on;
	my.flare = on;
	my.move = on;
	my.beam = on; // if your engine supports it
	my.size = 30;
	my.function = particle_fade; // use the same particle_fade function that was used for the plasma jets
}

starter compute_score()
{
	while (1)
	{
		str_for_num(temp_str, score_value); // convert the value to string
		if (str_len(temp_str) == 1)
		{
			str_cpy(score_str, "0000000");
			str_cat(score_str, temp_str);
		}
		if (str_len(temp_str) == 2)
		{
			str_cpy(score_str, "000000");
			str_cat(score_str, temp_str);
		}
		if (str_len(temp_str) == 3)
		{
			str_cpy(score_str, "00000");
			str_cat(score_str, temp_str);
		}
		if (str_len(temp_str) == 4)
		{
			str_cpy(score_str, "0000");
			str_cat(score_str, temp_str);
		}
		if (str_len(temp_str) == 5)
		{
			str_cpy(score_str, "000");
			str_cat(score_str, temp_str);
		}
		if (str_len(temp_str) == 6)
		{
			str_cpy(score_str, "00");
			str_cat(score_str, temp_str);
		}
		if (str_len(temp_str) == 7)
		{
			str_cpy(score_str, "0");
			str_cat(score_str, temp_str);
		}
		if (str_len(temp_str) == 8)
		{
			str_cat(score_str, temp_str);
		}
		wait (1);
	}
}

starter init_logical()
{
	mouse_range = 5000; // the objects are sensitive to mouse clicks even if the pointer is 5000 quants away
	while ((tile1 == null) || (tile2 == null) || (tile3 == null) || (tile4 == null) || (tile5 == null) 
		|| (tile6 == null) || (tile7 == null) || (tile8 == null) || (tile9 == null)) {wait (1);}
	while (1)
	{
		status1 = 1 * (tile1.flag1 == on) + 2 * (tile1.flag2 == on) + 3 * (tile1.flag3 == on); // status1 can be 1, 2 or 3 (red, green or blue)
		status2 = 1 * (tile2.flag1 == on) + 2 * (tile2.flag2 == on) + 3 * (tile2.flag3 == on); // status2 can be 1, 2 or 3 (red, green or blue)
		status3 = 1 * (tile3.flag1 == on) + 2 * (tile3.flag2 == on) + 3 * (tile3.flag3 == on); // status3 can be 1, 2 or 3 (red, green or blue)
		status4 = 1 * (tile4.flag1 == on) + 2 * (tile4.flag2 == on) + 3 * (tile4.flag3 == on); // status4 can be 1, 2 or 3 (red, green or blue)
		status5 = 1 * (tile5.flag1 == on) + 2 * (tile5.flag2 == on) + 3 * (tile5.flag3 == on); // status5 can be 1, 2 or 3 (red, green or blue)
		status6 = 1 * (tile6.flag1 == on) + 2 * (tile6.flag2 == on) + 3 * (tile6.flag3 == on); // status6 can be 1, 2 or 3 (red, green or blue)
		status7 = 1 * (tile7.flag1 == on) + 2 * (tile7.flag2 == on) + 3 * (tile7.flag3 == on); // status7 can be 1, 2 or 3 (red, green or blue)
		status8 = 1 * (tile8.flag1 == on) + 2 * (tile8.flag2 == on) + 3 * (tile8.flag3 == on); // status8 can be 1, 2 or 3 (red, green or blue)
		status9 = 1 * (tile9.flag1 == on) + 2 * (tile9.flag2 == on) + 3 * (tile9.flag3 == on); // status9 can be 1, 2 or 3 (red, green or blue)
		if ((status1 == status2) && (status2 == status3)) // identical values on the first row?
		{
			if ((status4 == status5) && (status5 == status6)) // identical values on the second row?
			{
				give_bonus(); // no need to check the third row
				return; // get out of this function
			}
		}
		if ((status1 == status4) && (status4 == status7)) // identical values on the first column?
		{
			if ((status2 == status5) && (status5 == status8)) // identical values on the second column?
			{
				give_bonus(); // no need to check the third row
				return; // get out of this function
			}
		}
		wait (1);
	}
}

function compute_time()
{
	sleep (130); // wait about 2 minutes and 10 seconds, close to the end of the soundtrack
//	sleep (3); // force the landing
	landing = 1;
}

action landing_base
{
	lbase = my;
	my.invisible = on;
	my.passable = on;
	while (landing == 0) {wait (1);}
	my.invisible = off;
}

function move_human()
{
	my.passable = on;
	human = my;
	my.pan = 270;
	my.enable_touch = on;
	my.event = logical_help;
	while (my.y > -170)
	{
		my.y -= 1.4 * time; // move toward the logical board
		ent_cycle("walk", my.skill1); 
		my.skill1 += 5 * time; // "walk" animation speed 
		my.skill1 %= 100; // loop animation 
		wait (1);
	}
	// set a new camera position, good for the logical board
	ent_cycle ("walk", 25); // choose a convenient standing position (25 = experimental value)
	camera.x = -40;
	camera.y = -140;
	camera.z = -2100;
	camera.pan = 270;
	camera.tilt = -65;
	camera.roll = 0;
	mouse_map = logical_pcx;
	mouse_mode = 2;
	mouse_spot.x = 0; // restore the default mouse_spot values
	mouse_spot.y = 0;
	temp_bonus = 100; // get up to 100 armor points and 100 bullets
	sound_vol = 20; // decrease the volume of the exploding asteroids
	while (logical_ended == 0) // display the mouse pointer until the human solves the logical level
	{
		temp_bonus -= 0.1 * time;
		if (temp_bonus < 0) {temp_bonus = 0;}
		mouse_pos.x = pointer.x;
		mouse_pos.y = pointer.y;
		wait (1);	
	}		
	sleep (1);
	sound_vol = 100; // restore the volume of the exploding asteroids
	while (my.pan > 90) // rotate the human towards the ship
	{
		my.pan -= 25 * time;
		wait (1);
	}
	while (my.y < -100)
	{
		my.y += 1.4 * time; // move toward the ship now
		ent_cycle("walk", my.skill1); 
		my.skill1 += 5 * time; // "walk" animation speed 
		my.skill1 %= 100; // loop animation 
		wait (1);
	}
	ent_remove(my); // remove the human
	camera.x = 500; // restore the former camera position
	camera.y = -200;
	camera.z = -2000;
	vec_set(temp, player.x); // see the ship taking off from the base
	vec_sub(temp, camera.x); 
	vec_to_angle(camera.pan, temp); 
	while (minimum_bonus > 0) {wait (1);} // wait until the player gets all the bonus
	sleep (1); // wait 1 second
	fade_factor = 1000; // use few particles for the engines because the speed is big
	player.engine = on; // prepare to start the engine
	my = player; // tell the particle function that "my" is going to be the player
	plasma_jet(65, 63); // use the "real" set of vertices for the engine
	level2_ready = 1;
	while (vec_dist(camera.x, player.x) < 10000)
	{
		player.skill15 = min(100, vec_dist(player.x, lbase.x) / 10);
		player.x += (player.skill15 + 1) * time; // that's a value that grows from 1 * time to 101 * time
		player.z += 5 * time;
		engine_handle = ent_playsound (player, engine1_wav, 1000); // play the engine sound
		if (player.skill15 < 10000)
		{
			snd_tune(engine_handle, 0, (player.skill15), 0);
		}
		vec_set(temp, player.x); // follow the ship until it is 10,000 quants away
		vec_sub(temp, camera.x); 
		vec_to_angle(camera.pan, temp); 
		d3d_fogcolor1.red = max (0, (d3d_fogcolor1.red - 2 * time));
		d3d_fogcolor1.green = max (0, (d3d_fogcolor1.green - 2 * time));
		d3d_fogcolor1.blue = max (0, (d3d_fogcolor1.blue - 2 * time));
		wait (1);
	}
	fog_color = 0; // disable fog
	d3d_fogcolor1.red = 0;
	d3d_fogcolor1.green = 0;
	d3d_fogcolor1.blue = 0;
	level_load (level2_wmb); // load the next level
}

function logical_help()
{
	logical_txt.visible = on;
	sleep (5);
	logical_txt.visible = off;
}

action tile_1
{
	tile1 = my;
}

action tile_2
{
	tile2 = my;
}

action tile_3
{
	tile3 = my;
}

action tile_4
{
	tile4 = my;
}

action tile_5
{
	tile5 = my;
}

action tile_6
{
	tile6 = my;
}

action tile_7
{
	tile7 = my;
}

action tile_8
{
	tile8 = my;
}

action tile_9
{
	tile9 = my;
}

action h1
{
	my.ambient = -100;
	my.enable_click = on;
	my.event = h1_clicked;
}
	
function h1_clicked()
{
	my.ambient = 100;
	sleep (0.2);
	my.ambient = -100;
	status1 = 1 * (tile1.flag1 == on) + 2 * (tile1.flag2 == on) + 3 * (tile1.flag3 == on); // status1 can be 1, 2 or 3 (red, green or blue)
	status2 = 1 * (tile2.flag1 == on) + 2 * (tile2.flag2 == on) + 3 * (tile2.flag3 == on); // status2 can be 1, 2 or 3 (red, green or blue)
	status3 = 1 * (tile3.flag1 == on) + 2 * (tile3.flag2 == on) + 3 * (tile3.flag3 == on); // status3 can be 1, 2 or 3 (red, green or blue)
	if (status2 == 1) // tile2 is a red tile?
	{
		ent_morph(tile1, tilered_wmb); // then change into a red tile
		tile1.flag1 = off; // reset all the flags
		tile1.flag2 = off;
		tile1.flag3 = off;
		tile1.flag1 = on; // tile1 will be a red tile from now on
	} 
	if (status2 == 2) // tile2 is a green tile?
	{
		ent_morph(tile1, tilegreen_wmb); // then change into a green tile
		tile1.flag1 = off; // // reset all the flags 
		tile1.flag2 = off;
		tile1.flag3 = off;
		tile1.flag2 = on; // tile1 will be a green tile from now on
	} 
	if (status2 == 3) // tile2 is a blue tile?
	{
		ent_morph(tile1, tileblue_wmb); // then change into a blue tile
		tile1.flag1 = off; // // reset all the flags 
		tile1.flag2 = off;
		tile1.flag3 = off;
		tile1.flag3 = on; // tile1 will be a blue tile from now on
	} 
	if (status3 == 1) // tile3 is a red tile?
	{
		ent_morph(tile2, tilered_wmb); // then change into a red tile
		tile2.flag1 = off; // reset all the flags
		tile2.flag2 = off;
		tile2.flag3 = off;
		tile2.flag1 = on; // tile2 will be a red tile from now on
	} 
	if (status3 == 2) // tile3 is a green tile?
	{
		ent_morph(tile2, tilegreen_wmb); // then change into a green tile
		tile2.flag1 = off; // // reset all the flags 
		tile2.flag2 = off;
		tile2.flag3 = off;
		tile2.flag2 = on; // tile2 will be a green tile from now on
	} 
	if (status3 == 3) // tile3 is a blue tile?
	{
		ent_morph(tile2, tileblue_wmb); // then change into a blue tile
		tile2.flag1 = off; // // reset all the flags 
		tile2.flag2 = off;
		tile2.flag3 = off;
		tile2.flag3 = on; // tile2 will be a blue tile from now on
	} 
	if (status1 == 1) // tile1 is a red tile?
	{
		ent_morph(tile3, tilered_wmb); // then change into a red tile
		tile3.flag1 = off; // reset all the flags
		tile3.flag2 = off;
		tile3.flag3 = off;
		tile3.flag1 = on; // tile3 will be a red tile from now on
	} 
	if (status1 == 2) // tile1 is a green tile?
	{
		ent_morph(tile3, tilegreen_wmb); // then change into a green tile
		tile3.flag1 = off; // // reset all the flags 
		tile3.flag2 = off;
		tile3.flag3 = off;
		tile3.flag2 = on; // tile3 will be a green tile from now on
	} 
	if (status1 == 3) // tile1 is a blue tile?
	{
		ent_morph(tile3, tileblue_wmb); // then change into a blue tile
		tile3.flag1 = off; // // reset all the flags 
		tile3.flag2 = off;
		tile3.flag3 = off;
		tile3.flag3 = on; // tile3 will be a blue tile from now on
	} 
}

action h2
{
	my.ambient = -100;
	my.enable_click = on;
	my.event = h2_clicked;
}
	
function h2_clicked()
{
	my.ambient = 100;
	sleep (0.2);
	my.ambient = -100;
	status4 = 1 * (tile4.flag1 == on) + 2 * (tile4.flag2 == on) + 3 * (tile4.flag3 == on); // status4 can be 1, 2 or 3 (red, green or blue)
	status5 = 1 * (tile5.flag1 == on) + 2 * (tile5.flag2 == on) + 3 * (tile5.flag3 == on); // status5 can be 1, 2 or 3 (red, green or blue)
	status6 = 1 * (tile6.flag1 == on) + 2 * (tile6.flag2 == on) + 3 * (tile6.flag3 == on); // status6 can be 1, 2 or 3 (red, green or blue)
	if (status5 == 1) // tile5 is a red tile?
	{
		ent_morph(tile4, tilered_wmb); // then change into a red tile
		tile4.flag1 = off; // reset all the flags
		tile4.flag2 = off;
		tile4.flag3 = off;
		tile4.flag1 = on; // tile4 will be a red tile from now on
	} 
	if (status5 == 2) // tile5 is a green tile?
	{
		ent_morph(tile4, tilegreen_wmb); // then change into a green tile
		tile4.flag1 = off; // // reset all the flags 
		tile4.flag2 = off;
		tile4.flag3 = off;
		tile4.flag2 = on; // tile4 will be a green tile from now on
	} 
	if (status5 == 3) // tile5 is a blue tile?
	{
		ent_morph(tile4, tileblue_wmb); // then change into a blue tile
		tile4.flag1 = off; // // reset all the flags 
		tile4.flag2 = off;
		tile4.flag3 = off;
		tile4.flag3 = on; // tile4 will be a blue tile from now on
	} 
	if (status6 == 1) // tile6 is a red tile?
	{
		ent_morph(tile5, tilered_wmb); // then change into a red tile
		tile5.flag1 = off; // reset all the flags
		tile5.flag2 = off;
		tile5.flag3 = off;
		tile5.flag1 = on; // tile5 will be a red tile from now on
	} 
	if (status6 == 2) // tile6 is a green tile?
	{
		ent_morph(tile5, tilegreen_wmb); // then change into a green tile
		tile5.flag1 = off; // // reset all the flags 
		tile5.flag2 = off;
		tile5.flag3 = off;
		tile5.flag2 = on; // tile5 will be a green tile from now on
	} 
	if (status6 == 3) // tile6 is a blue tile?
	{
		ent_morph(tile5, tileblue_wmb); // then change into a blue tile
		tile5.flag1 = off; // // reset all the flags 
		tile5.flag2 = off;
		tile5.flag3 = off;
		tile5.flag3 = on; // tile5 will be a blue tile from now on
	} 
	if (status4 == 1) // tile4 is a red tile?
	{
		ent_morph(tile6, tilered_wmb); // then change into a red tile
		tile6.flag1 = off; // reset all the flags
		tile6.flag2 = off;
		tile6.flag3 = off;
		tile6.flag1 = on; // tile6 will be a red tile from now on
	} 
	if (status4 == 2) // tile4 is a green tile?
	{
		ent_morph(tile6, tilegreen_wmb); // then change into a green tile
		tile6.flag1 = off; // // reset all the flags 
		tile6.flag2 = off;
		tile6.flag3 = off;
		tile6.flag2 = on; // tile6 will be a green tile from now on
	} 
	if (status4 == 3) // tile4 is a blue tile?
	{
		ent_morph(tile6, tileblue_wmb); // then change into a blue tile
		tile6.flag1 = off; // // reset all the flags 
		tile6.flag2 = off;
		tile6.flag3 = off;
		tile6.flag3 = on; // tile6 will be a blue tile from now on
	} 
}

action h3
{
	my.ambient = -100;
	my.enable_click = on;
	my.event = h3_clicked;
}
	
function h3_clicked()
{
	my.ambient = 100;
	sleep (0.2);
	my.ambient = -100;
	status7 = 1 * (tile7.flag1 == on) + 2 * (tile7.flag2 == on) + 3 * (tile7.flag3 == on); // status7 can be 1, 2 or 3 (red, green or blue)
	status8 = 1 * (tile8.flag1 == on) + 2 * (tile8.flag2 == on) + 3 * (tile8.flag3 == on); // status8 can be 1, 2 or 3 (red, green or blue)
	status9 = 1 * (tile9.flag1 == on) + 2 * (tile9.flag2 == on) + 3 * (tile9.flag3 == on); // status9 can be 1, 2 or 3 (red, green or blue)
	if (status8 == 1) // tile8 is a red tile?
	{
		ent_morph(tile7, tilered_wmb); // then change into a red tile
		tile7.flag1 = off; // reset all the flags
		tile7.flag2 = off;
		tile7.flag3 = off;
		tile7.flag1 = on; // tile7 will be a red tile from now on
	} 
	if (status8 == 2) // tile8 is a green tile?
	{
		ent_morph(tile7, tilegreen_wmb); // then change into a green tile
		tile7.flag1 = off; // // reset all the flags 
		tile7.flag2 = off;
		tile7.flag3 = off;
		tile7.flag2 = on; // tile7 will be a green tile from now on
	} 
	if (status8 == 3) // tile8 is a blue tile?
	{
		ent_morph(tile7, tileblue_wmb); // then change into a blue tile
		tile7.flag1 = off; // // reset all the flags 
		tile7.flag2 = off;
		tile7.flag3 = off;
		tile7.flag3 = on; // tile7 will be a blue tile from now on
	} 
	if (status9 == 1) // tile9 is a red tile?
	{
		ent_morph(tile8, tilered_wmb); // then change into a red tile
		tile8.flag1 = off; // reset all the flags
		tile8.flag2 = off;
		tile8.flag3 = off;
		tile8.flag1 = on; // tile8 will be a red tile from now on
	} 
	if (status9 == 2) // tile9 is a green tile?
	{
		ent_morph(tile8, tilegreen_wmb); // then change into a green tile
		tile8.flag1 = off; // // reset all the flags 
		tile8.flag2 = off;
		tile8.flag3 = off;
		tile8.flag2 = on; // tile8 will be a green tile from now on
	} 
	if (status9 == 3) // tile9 is a blue tile?
	{
		ent_morph(tile8, tileblue_wmb); // then change into a blue tile
		tile8.flag1 = off; // // reset all the flags 
		tile8.flag2 = off;
		tile8.flag3 = off;
		tile8.flag3 = on; // tile8 will be a blue tile from now on
	} 
	if (status7 == 1) // tile7 is a red tile?
	{
		ent_morph(tile9, tilered_wmb); // then change into a red tile
		tile9.flag1 = off; // reset all the flags
		tile9.flag2 = off;
		tile9.flag3 = off;
		tile9.flag1 = on; // tile9 will be a red tile from now on
	} 
	if (status7 == 2) // tile7 is a green tile?
	{
		ent_morph(tile9, tilegreen_wmb); // then change into a green tile
		tile9.flag1 = off; // // reset all the flags 
		tile9.flag2 = off;
		tile9.flag3 = off;
		tile9.flag2 = on; // tile9 will be a green tile from now on
	} 
	if (status7 == 3) // tile7 is a blue tile?
	{
		ent_morph(tile9, tileblue_wmb); // then change into a blue tile
		tile9.flag1 = off; // // reset all the flags 
		tile9.flag2 = off;
		tile9.flag3 = off;
		tile9.flag3 = on; // tile9 will be a blue tile from now on
	} 
}

action v1
{
	my.ambient = -100;
	my.enable_click = on;
	my.event = v1_clicked;
}
	
function v1_clicked()
{
	var status1;
	var status4;
	var status7;
	my.ambient = 100;
	sleep (0.2);
	my.ambient = -100;
	status1 = 1 * (tile1.flag1 == on) + 2 * (tile1.flag2 == on) + 3 * (tile1.flag3 == on); // status1 can be 1, 2 or 3 (red, green or blue)
	status4 = 1 * (tile4.flag1 == on) + 2 * (tile4.flag2 == on) + 3 * (tile4.flag3 == on); // status4 can be 1, 2 or 3 (red, green or blue)
	status7 = 1 * (tile7.flag1 == on) + 2 * (tile7.flag2 == on) + 3 * (tile7.flag3 == on); // status7 can be 1, 2 or 3 (red, green or blue)
	if (status4 == 1) // tile4 is a red tile?
	{
		ent_morph(tile1, tilered_wmb); // then change into a red tile
		tile1.flag1 = off; // reset all the flags
		tile1.flag2 = off;
		tile1.flag3 = off;
		tile1.flag1 = on; // tile1 will be a red tile from now on
	} 
	if (status4 == 2) // tile4 is a green tile?
	{
		ent_morph(tile1, tilegreen_wmb); // then change into a green tile
		tile1.flag1 = off; // // reset all the flags 
		tile1.flag2 = off;
		tile1.flag3 = off;
		tile1.flag2 = on; // tile1 will be a green tile from now on
	} 
	if (status4 == 3) // tile4 is a blue tile?
	{
		ent_morph(tile1, tileblue_wmb); // then change into a blue tile
		tile1.flag1 = off; // // reset all the flags 
		tile1.flag2 = off;
		tile1.flag3 = off;
		tile1.flag3 = on; // tile1 will be a blue tile from now on
	} 
	if (status7 == 1) // tile7 is a red tile?
	{
		ent_morph(tile4, tilered_wmb); // then change into a red tile
		tile4.flag1 = off; // reset all the flags
		tile4.flag2 = off;
		tile4.flag3 = off;
		tile4.flag1 = on; // tile4 will be a red tile from now on
	} 
	if (status7 == 2) // tile7 is a green tile?
	{
		ent_morph(tile4, tilegreen_wmb); // then change into a green tile
		tile4.flag1 = off; // // reset all the flags 
		tile4.flag2 = off;
		tile4.flag3 = off;
		tile4.flag2 = on; // tile4 will be a green tile from now on
	} 
	if (status7 == 3) // tile7 is a blue tile?
	{
		ent_morph(tile4, tileblue_wmb); // then change into a blue tile
		tile4.flag1 = off; // // reset all the flags 
		tile4.flag2 = off;
		tile4.flag3 = off;
		tile4.flag3 = on; // tile4 will be a blue tile from now on
	} 
	if (status1 == 1) // tile1 is a red tile?
	{
		ent_morph(tile7, tilered_wmb); // then change into a red tile
		tile7.flag1 = off; // reset all the flags
		tile7.flag2 = off;
		tile7.flag3 = off;
		tile7.flag1 = on; // tile7 will be a red tile from now on
	} 
	if (status1 == 2) // tile1 is a green tile?
	{
		ent_morph(tile7, tilegreen_wmb); // then change into a green tile
		tile7.flag1 = off; // // reset all the flags 
		tile7.flag2 = off;
		tile7.flag3 = off;
		tile7.flag2 = on; // tile7 will be a green tile from now on
	} 
	if (status1 == 3) // tile1 is a blue tile?
	{
		ent_morph(tile7, tileblue_wmb); // then change into a blue tile
		tile7.flag1 = off; // // reset all the flags 
		tile7.flag2 = off;
		tile7.flag3 = off;
		tile7.flag3 = on; // tile7 will be a blue tile from now on
	} 
}

action v2
{
	my.ambient = -100;
	my.enable_click = on;
	my.event = v2_clicked;
}
	
function v2_clicked()
{
	var status2;
	var status5;
	var status8;
	my.ambient = 100;
	sleep (0.2);
	my.ambient = -100;
	status2 = 1 * (tile2.flag1 == on) + 2 * (tile2.flag2 == on) + 3 * (tile2.flag3 == on); // status2 can be 1, 2 or 3 (red, green or blue)
	status5 = 1 * (tile5.flag1 == on) + 2 * (tile5.flag2 == on) + 3 * (tile5.flag3 == on); // status5 can be 1, 2 or 3 (red, green or blue)
	status8 = 1 * (tile8.flag1 == on) + 2 * (tile8.flag2 == on) + 3 * (tile8.flag3 == on); // status8 can be 1, 2 or 3 (red, green or blue)
	if (status5 == 1) // tile5 is a red tile?
	{
		ent_morph(tile2, tilered_wmb); // then change into a red tile
		tile2.flag1 = off; // reset all the flags
		tile2.flag2 = off;
		tile2.flag3 = off;
		tile2.flag1 = on; // tile2 will be a red tile from now on
	} 
	if (status5 == 2) // tile5 is a green tile?
	{
		ent_morph(tile2, tilegreen_wmb); // then change into a green tile
		tile2.flag1 = off; // // reset all the flags 
		tile2.flag2 = off;
		tile2.flag3 = off;
		tile2.flag2 = on; // tile2 will be a green tile from now on
	} 
	if (status5 == 3) // tile5 is a blue tile?
	{
		ent_morph(tile2, tileblue_wmb); // then change into a blue tile
		tile2.flag1 = off; // // reset all the flags 
		tile2.flag2 = off;
		tile2.flag3 = off;
		tile2.flag3 = on; // tile2 will be a blue tile from now on
	} 
	if (status8 == 1) // tile8 is a red tile?
	{
		ent_morph(tile5, tilered_wmb); // then change into a red tile
		tile5.flag1 = off; // reset all the flags
		tile5.flag2 = off;
		tile5.flag3 = off;
		tile5.flag1 = on; // tile5 will be a red tile from now on
	} 
	if (status8 == 2) // tile8 is a green tile?
	{
		ent_morph(tile5, tilegreen_wmb); // then change into a green tile
		tile5.flag1 = off; // // reset all the flags 
		tile5.flag2 = off;
		tile5.flag3 = off;
		tile5.flag2 = on; // tile5 will be a green tile from now on
	} 
	if (status8 == 3) // tile8 is a blue tile?
	{
		ent_morph(tile5, tileblue_wmb); // then change into a blue tile
		tile5.flag1 = off; // // reset all the flags 
		tile5.flag2 = off;
		tile5.flag3 = off;
		tile5.flag3 = on; // tile5 will be a blue tile from now on
	} 
	if (status2 == 1) // tile2 is a red tile?
	{
		ent_morph(tile8, tilered_wmb); // then change into a red tile
		tile8.flag1 = off; // reset all the flags
		tile8.flag2 = off;
		tile8.flag3 = off;
		tile8.flag1 = on; // tile8 will be a red tile from now on
	} 
	if (status2 == 2) // tile2 is a green tile?
	{
		ent_morph(tile8, tilegreen_wmb); // then change into a green tile
		tile8.flag1 = off; // // reset all the flags 
		tile8.flag2 = off;
		tile8.flag3 = off;
		tile8.flag2 = on; // tile8 will be a green tile from now on
	} 
	if (status2 == 3) // tile2 is a blue tile?
	{
		ent_morph(tile8, tileblue_wmb); // then change into a blue tile
		tile8.flag1 = off; // // reset all the flags 
		tile8.flag2 = off;
		tile8.flag3 = off;
		tile8.flag3 = on; // tile8 will be a blue tile from now on
	} 
}

action v3
{
	my.ambient = -100;
	my.enable_click = on;
	my.event = v3_clicked;
}
	
function v3_clicked()
{
	var status3;
	var status6;
	var status9;
	my.ambient = 100;
	sleep (0.2);
	my.ambient = -100;
	status3 = 1 * (tile3.flag1 == on) + 2 * (tile3.flag2 == on) + 3 * (tile3.flag3 == on); // status3 can be 1, 2 or 3 (red, green or blue)
	status6 = 1 * (tile6.flag1 == on) + 2 * (tile6.flag2 == on) + 3 * (tile6.flag3 == on); // status6 can be 1, 2 or 3 (red, green or blue)
	status9 = 1 * (tile9.flag1 == on) + 2 * (tile9.flag2 == on) + 3 * (tile9.flag3 == on); // status9 can be 1, 2 or 3 (red, green or blue)
	if (status6 == 1) // tile6 is a red tile?
	{
		ent_morph(tile3, tilered_wmb); // then change into a red tile
		tile3.flag1 = off; // reset all the flags
		tile3.flag2 = off;
		tile3.flag3 = off;
		tile3.flag1 = on; // tile3 will be a red tile from now on
	} 
	if (status6 == 2) // tile6 is a green tile?
	{
		ent_morph(tile3, tilegreen_wmb); // then change into a green tile
		tile3.flag1 = off; // // reset all the flags 
		tile3.flag2 = off;
		tile3.flag3 = off;
		tile3.flag2 = on; // tile3 will be a green tile from now on
	} 
	if (status6 == 3) // tile6 is a blue tile?
	{
		ent_morph(tile3, tileblue_wmb); // then change into a blue tile
		tile3.flag1 = off; // // reset all the flags 
		tile3.flag2 = off;
		tile3.flag3 = off;
		tile3.flag3 = on; // tile2 will be a blue tile from now on
	} 
	if (status9 == 1) // tile9 is a red tile?
	{
		ent_morph(tile6, tilered_wmb); // then change into a red tile
		tile6.flag1 = off; // reset all the flags
		tile6.flag2 = off;
		tile6.flag3 = off;
		tile6.flag1 = on; // tile6 will be a red tile from now on
	} 
	if (status9 == 2) // tile9 is a green tile?
	{
		ent_morph(tile6, tilegreen_wmb); // then change into a green tile
		tile6.flag1 = off; // // reset all the flags 
		tile6.flag2 = off;
		tile6.flag3 = off;
		tile6.flag2 = on; // tile6 will be a green tile from now on
	} 
	if (status9 == 3) // tile9 is a blue tile?
	{
		ent_morph(tile6, tileblue_wmb); // then change into a blue tile
		tile6.flag1 = off; // // reset all the flags 
		tile6.flag2 = off;
		tile6.flag3 = off;
		tile6.flag3 = on; // tile6 will be a blue tile from now on
	} 
	if (status3 == 1) // tile3 is a red tile?
	{
		ent_morph(tile9, tilered_wmb); // then change into a red tile
		tile9.flag1 = off; // reset all the flags
		tile9.flag2 = off;
		tile9.flag3 = off;
		tile9.flag1 = on; // tile9 will be a red tile from now on
	} 
	if (status3 == 2) // tile3 is a green tile?
	{
		ent_morph(tile9, tilegreen_wmb); // then change into a green tile
		tile9.flag1 = off; // // reset all the flags 
		tile9.flag2 = off;
		tile9.flag3 = off;
		tile9.flag2 = on; // tile9 will be a green tile from now on
	} 
	if (status3 == 3) // tile3 is a blue tile?
	{
		ent_morph(tile9, tileblue_wmb); // then change into a blue tile
		tile9.flag1 = off; // // reset all the flags 
		tile9.flag2 = off;
		tile9.flag3 = off;
		tile9.flag3 = on; // tile9 will be a blue tile from now on
	} 
}

function give_bonus()
{
	logical_ended = 1; // the logical level has ended
	mouse_mode = 0; // // so hide the mouse
	snd_play (victory_wav, 50, 0);
	sleep (2);
	minimum_bonus += temp_bonus; // add what's left of temp_bonus to minimum_bonus
	while (minimum_bonus > 0)
	{
		snd_play (bonus_wav, 100, 0);
		players_shield += 2;
		players_ammo += 2;
		minimum_bonus -= 2;
		sleep (0.1);
	}
	sleep (1);
}
