//////////////////////////////////////////////////////////////////////////

var video_mode = 7; // 800x600
var video_depth = 32; // 32 bit mode

var max_entities = 5000;

var game_started = 0; // will be set to 1 when the game starts
var engine_handle; // handle used for player's engine sound
var fade_factor = 20;
var particle_tail = 5;

///////////////////////////////////////////////////////////////////////////

bmap main_tga = <main.tga>; // main panel
bmap help_tga = <help.tga>; // help panel

bmap pointer1_tga = <pointer1.tga>; // mouse pointer
bmap pointer2_tga = <pointer2.tga>; // second version of the mouse pointer
bmap exit1_tga = <exit1.tga>;
bmap exit2_tga = <exit2.tga>;
bmap help1_tga = <help1.tga>;
bmap help2_tga = <help2.tga>;
bmap load1_tga = <load1.tga>;
bmap load2_tga = <load2.tga>;
bmap save1_tga = <save1.tga>;
bmap save2_tga = <save2.tga>;

bmap jet_tga = <jet.tga>; // engine jet

//////////////////////////////////////////////////////////////////////////

sound beep_sound = <beep.wav>;
sound mouse_wav = <mouse.wav>;
sound engine1_wav = <engine1.wav>;
sound menu_wav = <menu.wav>; // used for main / help menu switching

//////////////////////////////////////////////////////////////////////////

string intro_wmb = <intro.wmb>;
string level1_wmb = <level1.wmb>;

/////////////////////////////////////////////////////////////////////////

function mouse_over();
function exit_game();
function save_game();
function load_game();
function show_help();
function show_main();
function toggle_engines();
function plasma_jet(v1, v2); // v1 and v2 are the vertices for the jets
function particle_fade();
function particle_jet();
function start_level1();

/////////////////////////////////////////////////////////////////////////

define engine flag1; // starts / stops the player's engines

/////////////////////////////////////////////////////////////////////////

panel main_pan // main panel
{
	bmap = main_tga;
	layer = 20;
	pos_x = 0;
	pos_y = 0; // for now
	button = 397, 475, exit2_tga, exit1_tga, exit2_tga, exit_game, null, mouse_over;
	button = 559, 431, help2_tga, help1_tga, help2_tga, show_help, null, mouse_over;
	button = 647, 329, load2_tga, load1_tga, load2_tga, load_game, null, mouse_over;
	button = 681, 226, save2_tga, save1_tga, save2_tga, save_game, null, mouse_over;

	flags = overlay, refresh, visible;
}

panel help_pan // help panel
{
	bmap = help_tga;
	layer = 20;
	pos_x = 0; 
	pos_y = 601; // for now 
	on_click = show_main;

	flags = overlay, refresh, visible; // pos_x = 801 keeps the panel outside the screen for now
}

///////////////////////////////////////////////////////////////////////////

include <level1.wdl>;

//////////////////////////////////////////////////////////////////////////

function main()
{
	fps_max = 60;
	level_load (intro_wmb); // dummy level
	wait (3);
	time_smooth = 0.9; // use a value for "time" that is the average of the last 10 frames
	mouse_spot.x = 31; // ~ 63 / 2
	mouse_spot.y = 17; // ~ 35 / 2
	camera.x = 0; // choose a convenient camera position
	camera.y = 0;
	camera.z = 350;
	camera.tilt = -90; // and angle
	mouse_mode = 2; // show the pointer
	while (game_started == 0) // as long as we haven't started the game
	{
		mouse_pos.x = pointer.x;
		mouse_pos.y = pointer.y;
		if (random (1) > 0.95) // use the second bitmap for the pointer every 20 frames (or so)
		{
			mouse_map = pointer2_tga;
		}
		else
		{
			mouse_map = pointer1_tga;
		}
		wait (1); 		      
	}   
}	

action player_intro
{
	player = my;
	my.unlit = on; // don't receive light from outside
	my.roll = 20;
	if (version >= 6.00) // using A6?
	{
		my.ambient = -50; // better engine, renders brighter entities
	}
	else // using A5
	{
		my.ambient = 80; // weaker engine, needs bigger ambient values
	}
	my.enable_touch = on; // player's ship is sensitive to mouse touching
	my.enable_release = on; // mouse releasing
	my.enable_click = on; // mouse clicking
	my.event = toggle_engines;
}

function toggle_engines()
{
	if (event_type == event_touch) // ship touched with the mouse pointer?
	{
		my.engine = on; // start the engines
		if (snd_playing (engine_handle) == 0)
		{
			engine_handle = snd_loop (engine1_wav, 10, 0); // and play the engine sound if it isn't being played already
		}
	}
	if (event_type == event_release) // the mouse has moved away from the ship
	{	
		snd_stop (engine_handle); // so stop the sound
		my.engine = off; // and shut down the engines
	}
	if (event_type == event_click) // clicked with the mouse pointer?
	{	
		start_level1(); // load the first playable level
	}
	plasma_jet(52, 54); // update the status of the engines (set them on or off, depending on my.engine)
}

function mouse_over() // is executed when we are over the menu buttons
{
	snd_play (mouse_wav, 70, 0);
}	

function exit_game()
{
	exit;
}

function load_game() 
{
	beep;
}

function save_game()
{
	beep;
}

function show_help()
{
	while (main_pan.pos_y > -600)
	{
		main_pan.pos_y -= 10; // "10" gives the scrolling speed, use a number that divides 600 (5, 10, 12, 15, 20, 30, etc)
		help_pan.pos_y = main_pan.pos_y + 600; // keep help_pan glued to main_pan
		wait (1);
	}
	snd_play (menu_wav, 20, 0);
}

function show_main()
{
	while (main_pan.pos_y < 0)
	{
		main_pan.pos_y += 10; // "10" gives the scrolling speed, use a number that divides 600 (5, 10, 12, 15, 20, 30, etc)
		help_pan.pos_y = main_pan.pos_y + 600; // keep help_pan glued to main_pan
		wait (1);
	}
	snd_play (menu_wav, 20, 0);
}

function plasma_jet(v1, v2)
{
	proc_late();
	var jet_speed;
	var engine_left;
	var engine_right;
	while (my.engine == on)
	{
		vec_for_vertex(engine_left, my, v1);
		vec_for_vertex(engine_right, my, v2);
		engine_left.z -= 3; // small offset
		engine_right.z -= 3; // necessary for the playable levels
		temp.pan  = my.pan;
		temp.tilt = my.tilt;
		temp.roll = my.roll;
		jet_speed.x = -particle_tail;
		jet_speed.y = 0;
		jet_speed.z = 0;
		vec_rotate (jet_speed, temp);
		effect(particle_jet, 4, engine_left, jet_speed);
		effect(particle_jet, 4, engine_right, jet_speed);
		wait(1);		
	}
}

function particle_fade()
{
	my.alpha -= fade_factor * time;
	if (my.alpha <= 0) 
	{
		my.lifespan = 0;
	}
}

function particle_jet()
{
	my.alpha = 10 + random(90);
	my.bmap = jet_tga;
	my.flare = on;
	my.bright = on;
//	my.streak = on;
	my.move = on;
	my.size = 10;
	my.function = particle_fade; 
}

function start_level1()
{
	mouse_mode = 0; // hide the pointer
	snd_stop (engine_handle); // stop the engine sound
	main_pan.visible = off; // hide main_pan
	level_load (level1_wmb); // load the first playable level (runs level1.wdl when it is loaded)
}

